@@ -40,10 +40,14 @@ fn default_layout_merged_correctly() {
     let merged_layout = Layout {
         direction: Direction::Horizontal,
         borderless: false,
+        pane_name: None,
+        focus: None,
         parts: vec![
             Layout {
                 direction: Direction::Vertical,
                 borderless: true,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: Some(SplitSize::Fixed(1)),
                 run: Some(Run::Plugin(RunPlugin {
@@ -54,6 +58,8 @@ fn default_layout_merged_correctly() {
             Layout {
                 direction: Direction::Vertical,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: None,
                 run: None,
@@ -61,6 +67,8 @@ fn default_layout_merged_correctly() {
             Layout {
                 direction: Direction::Vertical,
                 borderless: true,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: Some(SplitSize::Fixed(2)),
                 run: Some(Run::Plugin(RunPlugin {
@@ -84,10 +92,14 @@ fn default_layout_new_tab_correct() {
     let merged_layout = Layout {
         direction: Direction::Horizontal,
         borderless: false,
+        pane_name: None,
+        focus: None,
         parts: vec![
             Layout {
                 direction: Direction::Vertical,
                 borderless: true,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: Some(SplitSize::Fixed(1)),
                 run: Some(Run::Plugin(RunPlugin {
@@ -98,6 +110,8 @@ fn default_layout_new_tab_correct() {
             Layout {
                 direction: Direction::Horizontal,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: None,
                 run: None,
@@ -105,6 +119,8 @@ fn default_layout_new_tab_correct() {
             Layout {
                 direction: Direction::Vertical,
                 borderless: true,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: Some(SplitSize::Fixed(2)),
                 run: Some(Run::Plugin(RunPlugin {
@@ -168,13 +184,19 @@ fn three_panes_with_tab_merged_correctly() {
     let merged_layout = Layout {
         direction: Direction::Horizontal,
         borderless: false,
+        pane_name: None,
+        focus: None,
         parts: vec![Layout {
             direction: Direction::Vertical,
             borderless: false,
+            pane_name: None,
+            focus: None,
             parts: vec![
                 Layout {
                     direction: Direction::Horizontal,
                     borderless: false,
+                    pane_name: None,
+                    focus: None,
                     parts: vec![],
                     split_size: Some(SplitSize::Percent(50.0)),
                     run: None,
@@ -182,10 +204,14 @@ fn three_panes_with_tab_merged_correctly() {
                 Layout {
                     direction: Direction::Horizontal,
                     borderless: false,
+                    pane_name: None,
+                    focus: None,
                     parts: vec![
                         Layout {
                             direction: Direction::Vertical,
                             borderless: false,
+                            pane_name: None,
+                            focus: None,
                             parts: vec![],
                             split_size: Some(SplitSize::Percent(50.0)),
                             run: None,
@@ -193,6 +219,8 @@ fn three_panes_with_tab_merged_correctly() {
                         Layout {
                             direction: Direction::Vertical,
                             borderless: false,
+                            pane_name: None,
+                            focus: None,
                             parts: vec![],
                             split_size: Some(SplitSize::Percent(50.0)),
                             run: None,
@@ -220,9 +248,13 @@ fn three_panes_with_tab_new_tab_is_correct() {
     let merged_layout = Layout {
         direction: Direction::Horizontal,
         borderless: false,
+        pane_name: None,
+        focus: None,
         parts: vec![Layout {
             direction: Direction::Horizontal,
             borderless: false,
+            pane_name: None,
+            focus: None,
             parts: vec![],
             split_size: None,
             run: None,
@@ -260,10 +292,14 @@ fn three_panes_with_tab_and_default_plugins_merged_correctly() {
     let merged_layout = Layout {
         direction: Direction::Horizontal,
         borderless: false,
+        pane_name: None,
+        focus: None,
         parts: vec![
             Layout {
                 direction: Direction::Vertical,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: Some(SplitSize::Fixed(1)),
                 run: Some(Run::Plugin(RunPlugin {
@@ -274,10 +310,14 @@ fn three_panes_with_tab_and_default_plugins_merged_correctly() {
             Layout {
                 direction: Direction::Vertical,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![
                     Layout {
                         direction: Direction::Horizontal,
                         borderless: false,
+                        pane_name: None,
+                        focus: None,
                         parts: vec![],
                         split_size: Some(SplitSize::Percent(50.0)),
                         run: None,
@@ -285,10 +325,14 @@ fn three_panes_with_tab_and_default_plugins_merged_correctly() {
                     Layout {
                         direction: Direction::Horizontal,
                         borderless: false,
+                        pane_name: None,
+                        focus: None,
                         parts: vec![
                             Layout {
                                 direction: Direction::Vertical,
                                 borderless: false,
+                                pane_name: None,
+                                focus: None,
                                 parts: vec![],
                                 split_size: Some(SplitSize::Percent(50.0)),
                                 run: None,
@@ -296,6 +340,8 @@ fn three_panes_with_tab_and_default_plugins_merged_correctly() {
                             Layout {
                                 direction: Direction::Vertical,
                                 borderless: false,
+                                pane_name: None,
+                                focus: None,
                                 parts: vec![],
                                 split_size: Some(SplitSize::Percent(50.0)),
                                 run: None,
@@ -311,6 +357,8 @@ fn three_panes_with_tab_and_default_plugins_merged_correctly() {
             Layout {
                 direction: Direction::Vertical,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: Some(SplitSize::Fixed(2)),
                 run: Some(Run::Plugin(RunPlugin {
@@ -334,10 +382,14 @@ fn three_panes_with_tab_and_default_plugins_new_tab_is_correct() {
     let merged_layout = Layout {
         direction: Direction::Horizontal,
         borderless: false,
+        pane_name: None,
+        focus: None,
         parts: vec![
             Layout {
                 direction: Direction::Vertical,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: Some(SplitSize::Fixed(1)),
                 run: Some(Run::Plugin(RunPlugin {
@@ -348,6 +400,8 @@ fn three_panes_with_tab_and_default_plugins_new_tab_is_correct() {
             Layout {
                 direction: Direction::Horizontal,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: None,
                 run: None,
@@ -355,6 +409,8 @@ fn three_panes_with_tab_and_default_plugins_new_tab_is_correct() {
             Layout {
                 direction: Direction::Vertical,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: Some(SplitSize::Fixed(2)),
                 run: Some(Run::Plugin(RunPlugin {
@@ -396,14 +452,20 @@ fn deeply_nested_tab_merged_correctly() {
     let merged_layout = Layout {
         direction: Direction::Horizontal,
         borderless: false,
+        pane_name: None,
+        focus: None,
         parts: vec![
             Layout {
                 direction: Direction::Vertical,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![
                     Layout {
                         direction: Direction::Horizontal,
                         borderless: false,
+                        pane_name: None,
+                        focus: None,
                         parts: vec![],
                         split_size: Some(SplitSize::Percent(21.0)),
                         run: None,
@@ -411,10 +473,14 @@ fn deeply_nested_tab_merged_correctly() {
                     Layout {
                         direction: Direction::Vertical,
                         borderless: false,
+                        pane_name: None,
+                        focus: None,
                         parts: vec![
                             Layout {
                                 direction: Direction::Horizontal,
                                 borderless: false,
+                                pane_name: None,
+                                focus: None,
                                 parts: vec![],
                                 split_size: Some(SplitSize::Percent(22.0)),
                                 run: None,
@@ -422,10 +488,14 @@ fn deeply_nested_tab_merged_correctly() {
                             Layout {
                                 direction: Direction::Horizontal,
                                 borderless: false,
+                                pane_name: None,
+                                focus: None,
                                 parts: vec![
                                     Layout {
                                         direction: Direction::Horizontal,
                                         borderless: false,
+                                        pane_name: None,
+                                        focus: None,
                                         parts: vec![],
                                         split_size: Some(SplitSize::Percent(23.0)),
                                         run: None,
@@ -433,6 +503,8 @@ fn deeply_nested_tab_merged_correctly() {
                                     Layout {
                                         direction: Direction::Horizontal,
                                         borderless: false,
+                                        pane_name: None,
+                                        focus: None,
                                         parts: vec![],
                                         split_size: Some(SplitSize::Percent(24.0)),
                                         run: None,
@@ -452,6 +524,8 @@ fn deeply_nested_tab_merged_correctly() {
             Layout {
                 direction: Direction::Vertical,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: Some(SplitSize::Percent(15.0)),
                 run: None,
@@ -459,6 +533,8 @@ fn deeply_nested_tab_merged_correctly() {
             Layout {
                 direction: Direction::Vertical,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: Some(SplitSize::Percent(15.0)),
                 run: None,
@@ -466,6 +542,8 @@ fn deeply_nested_tab_merged_correctly() {
             Layout {
                 direction: Direction::Vertical,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: Some(SplitSize::Percent(15.0)),
                 run: None,
@@ -504,10 +582,14 @@ fn three_tabs_tab_one_merged_correctly() {
     let merged_layout = Layout {
         direction: Direction::Vertical,
         borderless: false,
+        pane_name: None,
+        focus: None,
         parts: vec![
             Layout {
                 direction: Direction::Horizontal,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: Some(SplitSize::Percent(50.0)),
                 run: None,
@@ -515,6 +597,8 @@ fn three_tabs_tab_one_merged_correctly() {
             Layout {
                 direction: Direction::Horizontal,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: None,
                 run: None,
@@ -539,14 +623,20 @@ fn three_tabs_tab_two_merged_correctly() {
     let merged_layout = Layout {
         direction: Direction::Vertical,
         borderless: false,
+        pane_name: None,
+        focus: None,
         parts: vec![
             Layout {
                 direction: Direction::Horizontal,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![
                     Layout {
                         direction: Direction::Horizontal,
                         borderless: false,
+                        pane_name: None,
+                        focus: None,
                         parts: vec![],
                         split_size: Some(SplitSize::Percent(50.0)),
                         run: None,
@@ -554,6 +644,8 @@ fn three_tabs_tab_two_merged_correctly() {
                     Layout {
                         direction: Direction::Horizontal,
                         borderless: false,
+                        pane_name: None,
+                        focus: None,
                         parts: vec![],
                         split_size: None,
                         run: None,
@@ -565,6 +657,8 @@ fn three_tabs_tab_two_merged_correctly() {
             Layout {
                 direction: Direction::Horizontal,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: None,
                 run: None,
@@ -589,14 +683,20 @@ fn three_tabs_tab_three_merged_correctly() {
     let merged_layout = Layout {
         direction: Direction::Vertical,
         borderless: false,
+        pane_name: None,
+        focus: None,
         parts: vec![
             Layout {
                 direction: Direction::Vertical,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![
                     Layout {
                         direction: Direction::Vertical,
                         borderless: false,
+                        pane_name: None,
+                        focus: None,
                         parts: vec![],
                         split_size: Some(SplitSize::Percent(50.0)),
                         run: None,
@@ -604,6 +704,8 @@ fn three_tabs_tab_three_merged_correctly() {
                     Layout {
                         direction: Direction::Horizontal,
                         borderless: false,
+                        pane_name: None,
+                        focus: None,
                         parts: vec![],
                         split_size: None,
                         run: None,
@@ -615,6 +717,8 @@ fn three_tabs_tab_three_merged_correctly() {
             Layout {
                 direction: Direction::Horizontal,
                 borderless: false,
+                pane_name: None,
+                focus: None,
                 parts: vec![],
                 split_size: None,
                 run: None,
@@ -650,9 +754,13 @@ fn no_tabs_merged_correctly() {
     let merged_layout = Layout {
         direction: Direction::Horizontal,
         borderless: false,
+        pane_name: None,
+        focus: None,
         parts: vec![Layout {
             direction: Direction::Horizontal,
             borderless: false,
+            pane_name: None,
+            focus: None,
             parts: vec![],
             split_size: None,
             run: None,
@@ -699,6 +807,8 @@ fn no_layout_template_merged_correctly() {
                     split_size: None,
                     run: None,
                     borderless: false,
+                    pane_name: None,
+                    focus: None,
                 },
                 Layout {
                     direction: Direction::Horizontal,
@@ -706,15 +816,21 @@ fn no_layout_template_merged_correctly() {
                     split_size: None,
                     run: None,
                     borderless: false,
+                    pane_name: None,
+                    focus: None,
                 },
             ],
             split_size: None,
             run: None,
             borderless: false,
+            pane_name: None,
+            focus: None,
         }],
         split_size: None,
         run: None,
         borderless: false,
+        pane_name: None,
+        focus: None,
     };
 
     assert_eq!(merged_layout, tab_layout.try_into().unwrap());
